==> dkaceg-1.0.7.tar.gz: dkaceg-1.0.7/dkaceg/webdriver/support/get_elements/FindElements.py <==
from bs4 import BeautifulSoup
from .MatchAttributes import find_the_elements_by_event,xpath_soupreq
import requests
import json
def get_the_analysis(bot_id,multiple_element):
    found=False
    message=""
    send_bot_id=bot_id
    if(multiple_element==True):
        send_bot_id=send_bot_id+"_repeat"
    response=requests.post("https://jpzu5bjwzg.execute-api.us-east-2.amazonaws.com/default/read_bot_analysis",data=json.dumps({"bot_id":send_bot_id}),headers={"content-type":"application/json"}).json()
    found=response["status"]
    analysis=response["analysis"]
    if(found==False):
        message=response["message"]
    return analysis,found,message
def change_analysis(analysis):
    new_analysis={}
    for event_number in analysis:
        event_name=list(analysis[event_number].keys())[0]
        new_analysis=analysis[event_number][event_name]
        break
    try:
        new_analysis["Event"]["xlength"]=int(new_analysis["Event"]["xlength"])
    except:
        pass
    try:
        new_analysis["Parent"]["xlength"]=int(new_analysis["Parent"]["xlength"])
    except:
        pass
    return new_analysis
def get_the_elements_by_bot_id(page_source,bot_id,driver,multiple_element):
    analysis,found,message=get_the_analysis(bot_id,multiple_element)
    if(found==False):
        print(message)
        return None
    reqsoup=BeautifulSoup(page_source,'html.parser')
    analysis=change_analysis(analysis)
    elements=find_the_elements_by_event(reqsoup,page_source,analysis)
    if(multiple_element==False):
        element=driver.find_element_by_xpath(xpath_soupreq(elements[0]))
    else:
        element=[]
        for el in elements:
            element.append(driver.find_element_by_xpath(xpath_soupreq(el)))
    return element

==> dkaceg-1.0.8.tar.gz: dkaceg-1.0.8/dkaceg/webdriver/support/get_elements/FindElements.py <==
from bs4 import BeautifulSoup
from .MatchAttributes import find_the_elements_by_event,xpath_soupreq
import requests
import json
def get_the_analysis(bot_id,multiple_element):
    found=False
    message=""
    send_bot_id=bot_id
    if(multiple_element==True):
        send_bot_id=send_bot_id+"_repeat"
    response=requests.post("https://jpzu5bjwzg.execute-api.us-east-2.amazonaws.com/default/read_bot_analysis",data=json.dumps({"bot_id":send_bot_id}),headers={"content-type":"application/json"}).json()
    found=response["status"]
    analysis=response["analysis"]
    if(found==False):
        message=response["message"]
    return analysis,found,message
def change_analysis(analysis,multiple_element):
    new_analysis={}
    for event_number in analysis:
        event_name=list(analysis[event_number].keys())[0]
        new_analysis=analysis[event_number][event_name]
        break
    try:
        new_analysis["Event"]["xlength"]=int(new_analysis["Event"]["xlength"])
    except:
        pass
    try:
        new_analysis["Parent"]["xlength"]=int(new_analysis["Parent"]["xlength"])
    except:
        pass
    if(multiple_element==False):
        new_analysis["isrepeat"]=False
    return new_analysis
def get_the_elements_by_bot_id(page_source,bot_id,driver,multiple_element):
    analysis,found,message=get_the_analysis(bot_id,multiple_element)
    if(found==False):
        print(message)
        return None
    reqsoup=BeautifulSoup(page_source,'html.parser')
    analysis=change_analysis(analysis,multiple_element)
    elements=find_the_elements_by_event(reqsoup,page_source,analysis)
    if(multiple_element==False):
        element=driver.find_element_by_xpath(xpath_soupreq(elements[0]))
    else:
        element=[]
        for el in elements:
            element.append(driver.find_element_by_xpath(xpath_soupreq(el)))
    return element
